

"""This module offers a function to know something about sandorm 
"""

def whoissandorm():
  """ Here you get to know the secret.
  """
  print("Sandorm is a worm. It's the nickname for Chris in Berlin")
  





from distutils.core import setup

setup(
  name = 'sandorm',
  version = '1.0.1',
  py_modules = ['sandorm'],
  author = 'christian',
  author_email = 'hoefig@harung.de',
  url = 'http://www.harung.de',
  description = 'print sandorm information'
)
